Features
********


This section describes all features that are shipped with this package.


Scenario Features
=================

Base Classes
------------

.. autoclass:: balderhub.ant.lib.scenario_features.AntplusDeviceConfig
    :members:

.. autoclass:: balderhub.ant.lib.scenario_features.BaseAntplusDeviceProfile
    :members:

.. autoclass:: balderhub.ant.lib.scenario_features.AntplusTestCriteriaConfig
    :members:


General Ant+ Manager/Controller
-------------------------------

.. autoclass:: balderhub.ant.lib.scenario_features.AntNodeManagerFeature
    :members:

.. autoclass:: balderhub.ant.lib.scenario_features.AntplusControllerFeature
    :members:

Specific ANT+ Profile: Heart-Rate-Monitor (HRM)
-----------------------------------------------

.. autoclass:: balderhub.ant.lib.scenario_features.AntplusControllerHrmFeature
    :members:

.. autoclass:: balderhub.ant.lib.scenario_features.AntplusHrmDeviceConfig
    :members:

.. autoclass:: balderhub.ant.lib.scenario_features.AntplusHrmTestCriteriaConfig
    :members:

.. autoclass:: balderhub.ant.lib.scenario_features.HeartRateMonitorDeviceProfile
    :members:

Setup Features
==============

.. autoclass:: balderhub.ant.lib.setup_features.OpenantManagerFeature
    :members:

.. autoclass:: balderhub.ant.lib.setup_features.OpenantPlusControllerHrmFeature
    :members:
